/*******************************************************************************
 * This file is part of ODE Toolkit: a free application for solving systems of
 * ordinary differential equations.
 *  
 * Copyright (C) 2002-2011 Max Comstock, Beky Kotcon, Samantha Mesuro, Daniel Rozenfeld,
 * Anak Yodpinyanee, Andres Perez, Eric Doi, Richard Mehlinger, Steven Ehrlich,
 * Martin Hunt, George Tucker, Peter Scherpelz, Aaron Becker, Eric Harley,
 * Chris Moore
 * 
 * ODE Toolkit is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 * 
 * ODE Toolkit is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * ODE Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/

package data;

import java.awt.Color;

/**
 * The VisualProperties class holds information about objects such as Curves to
 * give to the Drawer.
 * 
 * @author Clinic 10-11
 */

public class VisualProperties {

	/** The color of the plot object */
	private Color color;
	/** The visibility of the plot object */
	private boolean isShown;

	/**
	 * Constructor for creating a VisualProperties
	 * 
	 * @param c
	 * @param s
	 */
	public VisualProperties(Color c, boolean s) {
		color = c;
		isShown = s;
	}

	/**
	 * Constructor for creating a default VisualProperties
	 */
	public VisualProperties() {
		this(Color.BLUE, true);
	}

	/**
	 * Returns the color of the plot object.
	 * 
	 * @return the color of the plot object
	 */
	public Color getColor() {
		return color;
	}

	/**
	 * Set the color of the plot object.
	 * 
	 * @param c
	 *            the new color of the plot object
	 */
	public void setColor(Color c) {
		color = c;
	}

	/**
	 * Returns the visibility of the plot object.
	 * 
	 * @return the visibility of the plot object
	 */
	public boolean isShown() {
		return isShown;
	}

	/**
	 * Set the visibility of the plot object.
	 * 
	 * @param s
	 *            the new visibility of the plot object
	 */
	public void showHide(boolean s) {
		isShown = s;
	}
}
