/*******************************************************************************
 * This file is part of ODE Toolkit: a free application for solving systems of
 * ordinary differential equations.
 *  
 * Copyright (C) 2002-2011 Max Comstock, Beky Kotcon, Samantha Mesuro, Daniel Rozenfeld,
 * Anak Yodpinyanee, Andres Perez, Eric Doi, Richard Mehlinger, Steven Ehrlich,
 * Martin Hunt, George Tucker, Peter Scherpelz, Aaron Becker, Eric Harley,
 * Chris Moore
 * 
 * ODE Toolkit is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 * 
 * ODE Toolkit is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * ODE Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/

/* Generated By:JJTree: Do not edit this line. JJTParserState.java */

package parser;

import java.util.Stack;

import parser.nodes.Node;

class JJTParserState {
	private Stack<Node> _nodes;
	private Stack<Integer> _marks;

	private int _sp; // number of nodes on stack
	private int _mk; // current mark
	private boolean _nodeCreated;

	JJTParserState() {
		_nodes = new Stack<Node>();
		_marks = new Stack<Integer>();
		_sp = 0;
		_mk = 0;
	}

	/*
	 * Determines whether the current node was actually closed and pushed. This
	 * should only be called in the final user action of a node scope.
	 */
	boolean nodeCreated() {
		return _nodeCreated;
	}

	/*
	 * Call this to reinitialize the node stack. It is called automatically by
	 * the parser's ReInit() method.
	 */
	void reset() {
		_nodes.removeAllElements();
		_marks.removeAllElements();
		_sp = 0;
		_mk = 0;
	}

	/*
	 * Returns the root node of the AST. It only makes sense to call this after
	 * a successful parse.
	 */
	Node rootNode() {
		return _nodes.elementAt(0);
	}

	/* Pushes a node on to the stack. */
	void pushNode(Node n) {
		_nodes.push(n);
		++_sp;
	}

	/*
	 * Returns the node on the top of the stack, and remove it from the stack.
	 */
	Node popNode() {
		if (--_sp < _mk) {
			_mk = (_marks.pop()).intValue();
		}
		return _nodes.pop();
	}

	/* Returns the node currently on the top of the stack. */
	Node peekNode() {
		return _nodes.peek();
	}

	/*
	 * Returns the number of children on the stack in the current node scope.
	 */
	int nodeArity() {
		return _sp - _mk;
	}

	void clearNodeScope(Node n) {
		while (_sp > _mk) {
			popNode();
		}
		_mk = (_marks.pop()).intValue();
	}

	void openNodeScope(Node n) {
		_marks.push(new Integer(_mk));
		_mk = _sp;
		n.jjtOpen();
	}

	/*
	 * A definite node is constructed from a specified number of children. That
	 * number of nodes are popped from the stack and made the children of the
	 * definite node. Then the definite node is pushed on to the stack.
	 */
	void closeNodeScope(Node n, int num) {
		_mk = (_marks.pop()).intValue();
		while (num-- > 0) {
			Node c = popNode();
			c.jjtSetParent(n);
			n.jjtAddChild(c, num);
		}
		n.jjtClose();
		pushNode(n);
		_nodeCreated = true;
	}

	/*
	 * A conditional node is constructed if its condition is true. All the nodes
	 * that have been pushed since the node was opened are made children of the
	 * the conditional node, which is then pushed on to the stack. If the
	 * condition is false the node is not constructed and they are left on the
	 * stack.
	 */
	void closeNodeScope(Node n, boolean condition) {
		if (condition) {
			int a = nodeArity();
			_mk = (_marks.pop()).intValue();
			while (a-- > 0) {
				Node c = popNode();
				c.jjtSetParent(n);
				n.jjtAddChild(c, a);
			}
			n.jjtClose();
			pushNode(n);
			_nodeCreated = true;
		} else {
			_mk = (_marks.pop()).intValue();
			_nodeCreated = false;
		}
	}
}
