/*******************************************************************************
 * This file is part of ODE Toolkit: a free application for solving systems of
 * ordinary differential equations.
 *  
 * Copyright (C) 2002-2011 Max Comstock, Beky Kotcon, Samantha Mesuro, Daniel Rozenfeld,
 * Anak Yodpinyanee, Andres Perez, Eric Doi, Richard Mehlinger, Steven Ehrlich,
 * Martin Hunt, George Tucker, Peter Scherpelz, Aaron Becker, Eric Harley,
 * Chris Moore
 * 
 * ODE Toolkit is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 * 
 * ODE Toolkit is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * ODE Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/

/* Generated By:JJTree: Do not edit this line. ASTidentifier.java */

package parser.nodes;

import parser.ParseException;
import parser.Parser;
import parser.ParserInterface;

public class ASTIdentifierNode extends SimpleNode {

	private String name;
	private boolean primed;
	private int varIndex;

	public ASTIdentifierNode(int id) {
		super(id);
		name = null;
		setPrimed(false);
		varIndex = -1;
	}

	public ASTIdentifierNode(Parser p, int id) {
		super(p, id);
		name = null;
		setPrimed(false);
		varIndex = -1;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

	public void setPrimed(boolean p) {
		primed = p;
	}

	public boolean getPrimed() {
		return primed;
	}

	@Override
	public void dump(String s) {
		System.out.println(s + "Identifier: " + name);
	}

	@Override
	public double evaluate(ParserInterface p) throws ParseException {
		if (primed) {
			if (varIndex < 0)
				varIndex = p.getVarIndex(name);
			if (varIndex < 0)
				throw new ParseException("Unrecognized identifier: " + name
						+ "'");
			try {
				return p.getSlopeUsingCurrentSymbolMap(varIndex);
			} catch (Exception e) {
				throw new ParseException(e.getMessage());
			}
		}
		return p.getSymbolDoubleValue(name);
	}

	@Override
	public boolean evaluateBoolean(ParserInterface p) throws ParseException {
		throw new ParseException("evaluateBoolean() called on non-boolean node");
	}

	@Override
	public void checkIdentifiers(ParserInterface p) throws ParseException {
		if (!p.isValidIdentifier(name)) {
			if (primed)
				throw new ParseException("Unrecognized identifier: " + name
						+ "'");
			else
				throw new ParseException("Unrecognized identifier: " + name);
		}
		if (primed && !p.getPrimeAllowed())
			throw new ParseException();
	}

	@Override
	public boolean containsODEIdentifier(ParserInterface p) {
		return p.hasODEVarNamed(name);
	}
}
